#
# spec file for package unetbootin
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rev 657

Name:           unetbootin
Summary:        Universal Netboot Installer
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Version:        0.0.%{rev}
Release:        20.1
Url:            https://sourceforge.net/projects/unetbootin/
Source:         %{name}-source-%{rev}.tar.gz
Patch0:         %{name}-suse.patch
Patch1:         %{name}-locate-usb-devices.diff
Patch2:         %{name}-desktop.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel
# Requires syslinux, and that only exists for the following arches:
ExclusiveArch:  %ix86 x86_64
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Requires:       mtools
# Remove when p7zip-full is in all products
%if 0%{suse_version} > 1500
Requires:       p7zip-full
%else
Requires:       p7zip
%endif
Requires:       syslinux
Requires:       udev
Requires:       util-linux
Requires:       xdg-utils

%description
UNetbootin allows for the installation of various Linux/BSD distributions
to a partition or USB drive, so it's no different from a standard install,
only it doesn't need a CD. It can create a dual-boot install,
or replace the existing OS entirely.

%prep
%setup -q -c -n %{name}
%patch0
%patch1
%patch2
# rpmlint: wrong-file-end-of-line-encoding
sed -i 's/\r$//' README.TXT

%build
lupdate unetbootin.pro
lrelease unetbootin.pro
qmake QMAKE_CXXFLAGS="%optflags" "DEFINES += NOSTATIC" "RESOURCES -= unetbootin.qrc"
make %{?_smp_mflags}

%install
install -D -m 0755 %{name} %{buildroot}%{_sbindir}/%{name}
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -D -m 0644 unetbootin_*.qm %{buildroot}%{_datadir}/%{name}

for i in 16 22 24 32 48 64 128 192 256 ; do
  install -D -m 0644 unetbootin_"$i".png %buildroot%{_datadir}/icons/hicolor/"$i"x"$i"/apps/%{name}.png;
done

install -D -m 0644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc README.TXT
%{_sbindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z binary needed by unetbootin was
  moved to this package (see bsc#899627 for more details about
  this change)
* Tue Dec 26 2017 joerg.lorenzen@ki.tng.de
- update to revision 657
* Thu Aug  3 2017 joerg.lorenzen@ki.tng.de
- update to revision 655
- added Leap_42.3 to supported versions
- fixed unetbootin-locate-usb-devices.diff
* Sat Jun 17 2017 joerg.lorenzen@ki.tng.de
- update to revision 647
- change selectable openSUSE versions only to supported versions:
  13.2, Leap_42.1, Leap_42.2, Tumbleweed, Factory
* Tue Jun 28 2016 chris@computersalat.de
- rebase patches
- fix changelog
* Wed Jun 22 2016 ecsos@opensuse.org
- change selectable openSUSE versions only to supported versions:
  13.1, 13.2, Leap_42.1, Tumbleweed, Factory
- change my old email to the new one in previous changes
* Mon Jun 20 2016 joerg.lorenzen@ki.tng.de
- update to revision 625
* Mon Dec  7 2015 dmueller@suse.com
- exclude from build on aarch64, not installable
* Tue Aug 11 2015 joerg.lorenzen@ki.tng.de
- update to revision 613
- removed source file unetbootin.desktop and added patch
  unetbootin-desktop.patch to install original desktop file
- build with %%optflags
- some clean ups in specfile
* Thu Jan 15 2015 hpj@urpla.net
- slightly clean up unetbootin-locate-usb-devices.diff patch
* Thu Dec 11 2014 hpj@urpla.net
- locate usb drives via /dev/disk/py-path in order to workaround
  udev issues
* Sun Nov  9 2014 ecsos@opensuse.org
- change selectable openSUSE versions only to supported versions:
  12.3, 13.1, 13.2, Tumbleweed, Factory
* Sun Sep  7 2014 ecsos@opensuse.org
- update to 608
* Mon May  5 2014 ecsos@opensuse.org
- update to 603
- add unetbootin.desktop
- rework suse patch
* Wed Jul 17 2013 chris@computersalat.de
- update to 585
- rework suse patch
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
* Fri May 11 2012 chris@computersalat.de
- update to 575
- rework suse patch
* Wed Jun  1 2011 prusnak@opensuse.org
- updated to 549
* Thu Mar 24 2011 chris@computersalat.de
- update to 506
- reworked suse patch
* Sat Feb  5 2011 chris@computersalat.de
- update to 502
* Fri Oct 22 2010 chris@computersalat.de
- update to revision 494
- added suse patch
* Mon Apr 26 2010 prusnak@suse.cz
- updated to revision 433
* Mon Oct  5 2009 prusnak@suse.cz
- updated to revision 372
* Mon Jun 15 2009 prusnak@suse.cz
- updated to revision 356
* Mon Jun  1 2009 prusnak@suse.cz
- updated to revision 344
* Wed Dec 10 2008 prusnak@suse.cz
- updated to revision 301
* Mon Aug 18 2008 prusnak@suse.cz
- created package - revision 272
